/**
	$Id: DynamicQueryWrapper.java 6132 2012-09-14 10:29:16Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.plugins;

import java.sql.SQLException;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.DynamicQuery;
import net.sf.basedb.core.query.ResultIterator;
import net.sf.basedb.core.query.SqlQuery;
import net.sf.basedb.core.query.SqlResult;

/**
	A query wrapper for {@link DynamicQuery}:s.
	
	@author nicklas
	@version 2.2
	@base.modified $Date: 2012-09-14 12:29:16 +0200 (fr, 14 sep 2012) $
*/
public class DynamicQueryWrapper
	implements QueryWrapper<SqlResult>
{
	private final SqlQuery query;
	private int counter = 0;
	private int colIndex;

	/**
		Create a new query wrapper.
		@param query The query
	*/
	public DynamicQueryWrapper(SqlQuery query)
	{
		this.query = query;
	}
	
	/**
		Calls {@link DynamicQuery#iterate(DbControl)}
	*/
	@Override
	public ResultIterator<SqlResult> iterate(DbControl dc)
	{
		return query.iterate(dc);
	}

	/**
		Keeps a counter which is incremented at each call to this method.
		Starts at 0.
	*/
	@Override
	public int getId(SqlResult item)
	{
		colIndex = 0;
		return counter++;
	}

	/**
		Calls {@link SqlResult#getObject(int)} and increases the column index
		for each call. Expects this method to be called in the order the properties 
		are selected.
	*/
	@Override
	public Object getData(DbControl dc, ExportedProperty exportedProperty, SqlResult item)
		throws SQLException
	{
		colIndex++;
		return item.getObject(colIndex);
	}

}
