/*
	$Id: ReporterScoreQuery.java 4517 2008-09-11 20:11:02Z jari $
	
	 Copyright (C) 2006 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import org.hibernate.StatelessSession;

import net.sf.basedb.core.data.ReporterListScoreData;
import net.sf.basedb.core.signal.SignalException;

/**
	This is a temporary solution to query against the reporter list's 
	score. This class will be replaced by a more generic query functionality in the future.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2008-09-11 22:11:02 +0200 (to, 11 sep 2008) $
*/
public class ReporterScoreQuery
	extends AbstractEntityQuery
{

	/**
		Create a new query for the specified item, using the default optional
		runtime filter.
	*/
	ReporterScoreQuery()
	{
		super(Item.REPORTERSCORE, ReporterListScoreData.class.getName(), true);
	}

	/**
		Execute the query and return the results as an iterator.
		@param dc The <code>DbControl</code> used to access the database
			and check permissions
		@throws BaseException If there is an error
	*/
	public ReporterScoreResultIterator iterate(DbControl dc)
		throws BaseException
	{
		long totalCount = -1;
		ScrollIterator<ReporterListScoreData> result = null;
		SessionControl sc = dc.getSessionControl();
		enableFilters(dc);
		try
		{
			StatelessSession session = dc.getStatelessSession();
			// Load the total count if it is requested
			if (isReturningTotalCount())
			{
				totalCount = QueryExecutor.loadData(Long.class, getCountHqlQuery(dc), session, sc);
			}
			
			// Load the results
			result = 
				QueryExecutor.loadIterator(ReporterListScoreData.class, getMainHqlQuery(dc), session, sc);
		}
		catch (InterruptedException ex)
		{
			throw new SignalException("Aborted by user", ex);
		}
		finally
		{
			disableFilters(dc);
		}
		return new ReporterScoreResultIterator(result, dc, totalCount);		
	}

}
