/*
	$Id: PasswordData.java 6356 2013-11-26 11:53:09Z nicklas $

	Copyright (C) 2005, 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import net.sf.basedb.core.User;

/**
	This class holds the password for a user. It has a one-to-one
	relationship with the {@link UserData} class. We have enabled proxies
	to avoid loading passwords unless it is necessary. The second-level
	cache must never be enabled for this class.

	@author Nicklas
	@version 2.0
	@see <a href="../../../../../../html/developer/api/data_api.authentication.html">Developer documentation: User authentication</a>
	@hibernate.class table="`Passwords`" lazy="true"
*/
public class PasswordData
	extends BasicData
{

	public PasswordData()
	{}

	private String cryptedPassword;
	/**
		Get the crypted password.
		@hibernate.property column="`crypted_password`" type="string" length="255" not-null="false"
		@since 3.0
	*/
	@PropertyPathProtected
	public String getCryptedPassword()
	{
		return cryptedPassword;
	}
	/**
		Set the encrypted password. The password should be encrypted with
		{@link User#encryptPassword(String)}.
		@since 3.0
	*/
	public void setCryptedPassword(String cryptedPassword)
	{
		this.cryptedPassword = cryptedPassword;
	}

	
	private UserData user;
	/**
		Get the user this password is referring to.
		@hibernate.one-to-one class="net.sf.basedb.core.data.UserData"
	*/
	public UserData getUser()
	{
		return user;
	}
	void setUser(UserData user)
	{
		this.user = user;
	}

}
