/*
	$Id: WellData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

import net.sf.basedb.core.data.annotations.AnnotationLink;

/**
	This class holds information about a well on a plate.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.Well
	@see <a href="../../../../../../html/developer/api/data_api.plates.html">Developer documentation: Array LIMS (plates)</a>
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
	@hibernate.class table="`Wells`" lazy="true"
*/
public class WellData
	extends BasicData
	implements AnnotatableData
{

	public WellData()
	{}

	/*
		From the AnnotatableData interface
		-------------------------------------------
	*/
	private AnnotationSetData annotationSet;
	@Override
	public AnnotationSetData getAnnotationSet()
	{
		return annotationSet;
	}
	@Override
	public void setAnnotationSet(AnnotationSetData annotationSet)
	{
		this.annotationSet = annotationSet;
	}
	@Override
	public Set<AnnotationLink> getAnnotations()
	{
		return null;
	}
	void setAnnotations(Set<AnnotationLink> annotations)
	{}
	// -------------------------------------------
	
	private PlateData plate;
	/**
		The plate this well belongs to.
		@see PlateData#getWells()
		@hibernate.many-to-one column="`plate_id`" not-null="true" outer-join="false" update="false"
	*/
	public PlateData getPlate()
	{
		return plate;
	}
	public void setPlate(PlateData plate)
	{
		this.plate = plate;
	}

	private int row;
	/**
		The row coordinate of this well.
		@hibernate.property column="`row`" type="int" not-null="true" update="false"
	*/
	public int getRow()
	{
		return row;
	}
	public void setRow(int row)
	{
		this.row = row;
	}
	
	private int column;
	/**
		The column coordinate of this well.
		@hibernate.property column="`column`" type="int" not-null="true" update="false"
	*/
	public int getColumn()
	{
		return column;
	}
	public void setColumn(int column)
	{
		this.column = column;
	}

	private WellData parent;
	/**
		If the plate was created from a {@link PlateMappingData} this property points to
		the well on the source plate used in the mapping.
		@see PlateMappingData#getDetails()
		@hibernate.many-to-one column="`parent_id`" not-null="false" outer-join="false" update="false"
	*/
	public WellData getParent()
	{
		return parent;
	}
	public void setParent(WellData parent)
	{
		this.parent = parent;
	}

	private ReporterData reporter;
	/**
		The reporter used in this well.
		@hibernate.many-to-one column="`reporter_id`" not-null="false" outer-join="false" update="false"
	*/
	public ReporterData getReporter()
	{
		return reporter;
	}
	public void setReporter(ReporterData reporter)
	{
		this.reporter = reporter;
	}

}
