/**
	$Id$

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.migrate;

import java.io.Writer;
import java.sql.ResultSet;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.dbengine.TableInfo.ColumnInfo;

/**
	Interface for factories that knows how to create result writers. 
	Implementations typically need to be able to format the exported
	values so that a specific target database knows how to import them.
	
	@author nicklas
	@since 3.1
	@base.modified $Date$
	@see ResultWriter
*/
public interface ResultWriterFactory 
{

	/**
		Create a new result writer.

		@param rs The result set that data should be taken from
		@param index The column index that the writer should read date from
		@param writer The writer to write the formatted output to
		@param column More information about the column that the writer should
			read from
		@return A result writer implementation
		@throws BaseException If the factory don't know how to create
			a writer for  the given column
	*/
	public ResultWriter create(ResultSet rs, int index, Writer writer, ColumnInfo column);
	
}
