/*
	$Id: ShareableUtil.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Group;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemResultIterator;
import net.sf.basedb.core.MultiPermissions;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.Project;
import net.sf.basedb.core.SharedItem;
import net.sf.basedb.core.User;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (må, 06 apr 2009) $
*/
public class ShareableUtil
{

	public static MultiPermissions getMultiPermissions(DbControl dc, Item itemType, Set<Integer> items)
		throws BaseException
	{
		Set<SharedItem> ss = new HashSet<SharedItem>(items.size());
		for (Integer id : items)
		{
			if (id != null)
			{
				SharedItem item = (SharedItem)itemType.getById(dc, id);
				if (item.hasPermission(Permission.SET_PERMISSION))
				{
					ss.add(item);
				}
			}
		}
		if (ss.size() == 0)
		{
			throw new PermissionDeniedException("You don't have permission to share any of the selected items.");
		}
		return new MultiPermissions(ss);
	}
	
	/**
	 	Gets a list with the projects, groups and users(in that order) that 
	 	an item is shared to.
	 	@param dc DbControl to use when accessing the database. 
	  	@param item The item that is shared
	  	@return A <code>List</code> with items implementing {@link net.sf.basedb.core.Nameable}
	  	@since 2.4
	*/
	public static List<Nameable> getSharedTo(DbControl dc, SharedItem item)
	{
		List<Nameable> sharees = new ArrayList<Nameable>();
		if (item.isShared())
		{
			MultiPermissions mp = new MultiPermissions(Collections.singleton(item));
			ItemResultIterator<Project> projects = mp.getProjects().iterate(dc);
			ItemResultIterator<Group> groups = mp.getGroups().iterate(dc);
			ItemResultIterator<User> users = mp.getUsers().iterate(dc);
			
			while (projects.hasNext())
			{
				sharees.add(projects.next());
			}		
			while (groups.hasNext())
			{
				sharees.add(groups.next());
			}
			while (users.hasNext())
			{
				sharees.add(users.next());
			}
		}
		return sharees;
	}
}
