/**
	$Id: ExtractToSampleTransformer.java 6799 2015-03-25 07:13:39Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.biomaterial;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Extract;
import net.sf.basedb.core.Include;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.Sample;
import net.sf.basedb.core.Type;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;
import net.sf.basedb.util.collections.BasicItemToIdTransformer;
import net.sf.basedb.util.collections.CollectionTransformer;
import net.sf.basedb.util.collections.MultiStepCollectionTransformer;

/**
	Collection transformer that given a collection of extracts finds
	their parent samples. Note that this transformer is only capable 
	of finding the samples that are immediate
	parents to the extract. If you want to follow pooled extracts up
	to samples, you should combine this transformer
	and a {@link ParentsTransformer} with the help of a
	{@link MultiStepCollectionTransformer}.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2015-03-25 08:13:39 +0100 (on, 25 mar 2015) $
	@deprecated In 3.5, use {@link net.sf.basedb.util.listable.ExtractToSampleTransformer} instead
*/
@Deprecated
public class ExtractToSampleTransformer
	implements CollectionTransformer<Extract, Sample>
{

	private DbControl dc;
	public ExtractToSampleTransformer(DbControl dc)
	{
		this.dc = dc;
	}
	
	/*
		From the CollectionTransformer interface
		----------------------------------------
	*/
	/**
		Add all samples that are parents to any of the extracts in the
		source collection.
		@return The number of samples added
	*/
	@Override
	public int transform(Collection<? extends Extract> extracts,
			Collection<? super Sample> samples)
	{
		// Copy source ID:s so we can use them as a parameter in the query
		Set<Integer> sourceIds = new HashSet<Integer>();
		BasicItemToIdTransformer idTransformer = new BasicItemToIdTransformer();
		idTransformer.transform(extracts, sourceIds);

		ItemQuery<Sample> query = createQuery();
		query.join(Hql.innerJoin("children", Item.EXTRACT.getAlias()));
		query.restrict(
			Restrictions.in(
				Hql.alias(Item.EXTRACT.getAlias()), 
				Expressions.parameter("extracts")
			)
		);
		query.setParameter("extracts", sourceIds, Type.INT);
		int size = samples.size();
		samples.addAll(query.list(dc));
		return samples.size() - size;
	}
	// -------------------------------------------------
	
	/**
		Create a query for loading samples. The default implemenation will
		simply load all samples. The restriction needed to locate the child
		extracts is automatically applied by the <code>transform</code>
		method. Subclasses may override this method to create an alternate query
		(for example, with more filters).
		@return A query object
	*/
	protected ItemQuery<Sample> createQuery()
	{
		ItemQuery<Sample> query = Sample.getQuery();
		query.include(Include.ALL);
		return query;
	}
	
}
