/**
	$Id$

	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.ma;

/**
	MA calculator for log2-transformed spot intensity values.
	
	@author nicklas
	@since 3.2.4
*/
public class Log2MACalculator 
	extends MACalculator 
{

	// 1 / 2 * log2(10) = ln(2) / 2 * ln(10)
	static final double INV_LOG2_10x2 = Math.log(2) / (Math.log(10) * 2);

	public Log2MACalculator()
	{}
	
	/**
		M = ch1 - ch2
		A = (ch1 + ch2) / (2 * log2(10))
	*/
	@Override
	public double[] MA(double ch1, double ch2) 
	{
		double[] MA = {ch1-ch2, (ch1+ch2)*INV_LOG2_10x2};
		return MA;
	}

	/**
		ch1 = old - factor
		ch2 = old + factor
	*/
	@Override
	public double[] correct(double ch1, double ch2, double factor) 
	{
		double[] result = {ch1-factor, ch2+factor};
		return result;
	}
	

}
