/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Inherit = function()
{
	var inherit = {};
	var noneSelectedRow;
	
	var selectedAnnotationTypes = [];
	var allowedAnnotationTypes = [];

	inherit.initPage = function()
	{
		// Buttons
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnSave', inherit.save);
		
		Buttons.addClickHandler('btnSelectAnnotationTypes', inherit.selectAnnotationTypes);
		Events.addEventHandler('btnSelectAnnotationTypes', 'base-selected', inherit.annotationTypeSelected);
		
		noneSelectedRow = Doc.element('none-selected').parentNode.parentNode;
		
		var annotationTypes = Data.json('page-data', 'annotation-types');
		if (annotationTypes)
		{
			for (var i = 0; i < annotationTypes.length; i++)
			{
				var at = annotationTypes[i];
				inherit.addAnnotationType(at);
				inherit.addMoreAnnotationTypeInfo(at);
			}
		}
	}
	
	
	inherit.selectAnnotationTypes = function(event)
	{
		var url = '&resetTemporary=1&tmpfilter:BOOLEAN:disableInheritance=false';
		url += '&exclude='+selectedAnnotationTypes.join(',');
		Dialogs.selectItem('ANNOTATIONTYPE', event.currentTarget.id, 1, url);
	}

	inherit.annotationTypeSelected = function(event)
	{
		var item = event.detail;
		if (Doc.element('at-'+item.id)) return;
		
		inherit.addAnnotationType(item);
		
		var request = Ajax.getXmlHttpRequest();
		var url = 'ajax.jsp?ID='+App.getSessionId();
		url += '&cmd=GetAnnotationTypeInfo&item_id=' + item.id;
		request.open("GET", url, true);
		request.send(null);
		Ajax.setReadyStateHandler(request, inherit.annotationTypeInfoLoaded, inherit.annotationTypeInfoLoaded);
	}
	
	inherit.annotationTypeInfoLoaded = function(request)
	{
		App.debug(request.responseText);
		var response = JSON.parse(request.responseText);
		if (response.status != 'ok')
		{
			App.debug(request.responseText);
			return;
		}
		
		inherit.addMoreAnnotationTypeInfo(response.annotationType);
	}
	
	inherit.addAnnotationType = function(item)
	{
		var frm = document.forms['annotations'];
		selectedAnnotationTypes[selectedAnnotationTypes.length] = item.id;
		
		var tr = document.createElement('tr');
		tr.className = 'highlight ' + (selectedAnnotationTypes.length % 2 == 0 ? 'bg-evenrow' : 'bg-oddrow');
		tr.id = 'at-'+item.id;

		var html = '<td class="cell">'+Strings.encodeTags(item.name)+'</td>';
		html += '<td class="cell">';
		html += '<select name="action_'+item.id+'" data-item-id="'+item.id+'">';
		html += '<option value="inherit" selected>Inherit from: ';
		html += '<option value="remove">Remove';
		html += '</select>';
		html += '</td>';
		html += '<td class="cell">';
		html += '<select name="from_'+item.id+'" id="from_'+item.id+'">';
		html += '<option value="">- any parent -';
		html += '</select>';
		html += '</td>'
		html += '<td class="cell">';
		html += '<label><input type="checkbox" name="nodup_'+item.id+'" checked>No duplicates</label> ';
		html += '<label><input type="checkbox" name="replace_'+item.id+'" checked>Replace existing</label>';
		html += '</td>';
		tr.innerHTML = html;
		
		var section = Doc.element('selectedAnnotationTypes');
		section.insertBefore(tr, noneSelectedRow);
		Doc.hide(noneSelectedRow);

		Forms.linkCheckboxesWithLabels(tr);
		Events.addEventHandler(frm['action_'+item.id], 'change', inherit.actionOnChange);
	}
	
	inherit.addMoreAnnotationTypeInfo = function(item)
	{
		if (item.disableInheritance)
		{
			var frm = document.forms['annotations'];
			var action = frm['action_'+item.id];
			action.length = 0;
			action[0] = new Option('Inheritance disabled');
			action.disabled = true;
			frm['from_'+item.id].disabled = true;
			frm['nodup_'+item.id].disabled = true;
			frm['replace_'+item.id].disabled = true;
			return;
		}
		
		allowedAnnotationTypes[allowedAnnotationTypes.length] = item.id;
		var selection = Doc.element('from_'+item.id);
		for (var i = 0; i < item.subtypes.length; i++)
		{
			var subtype = item.subtypes[i];
			selection[selection.length] = new Option(subtype.name + ' ('+subtype.itemType.toLowerCase()+')', subtype.id, false, subtype.selected);
		}
		
		if (item.plateTypes)
		{
			for (var i = 0; i < item.plateTypes.length; i++)
			{
				var plateType = atInfo.plateTypes[i];
				selection[selection.length] = new Option(plateType.name + ' (bioplate)', plateType.subtype.id);
			}
			if (selection.selectedIndex == 0) selection.selectedIndex = 1;
		}
	}
	

	inherit.actionOnChange = function(event)
	{
		var frm = document.forms['annotations'];
		
		var target = event.currentTarget;
		var itemId = Data.get(target, 'item-id');
		var disabled = target.value == 'remove';

		frm['from_'+itemId].disabled = disabled;
		frm['nodup_'+itemId].disabled = disabled;
		frm['replace_'+itemId].disabled = disabled;
	}
	
	inherit.save = function()
	{
		if (allowedAnnotationTypes.length == 0)
		{
			Forms.showNotification('btnSelectAnnotationTypes', 'Please select annotation types to inherit!');
			return;
		}
		var frm = document.forms['annotations'];
		frm.cmd.value = 'BatchInherit';
		Forms.addHidden(frm, 'annotationTypes', allowedAnnotationTypes.join(','));
		frm.submit();
	}
	
	return inherit;
}();

Doc.onLoad(Inherit.initPage);


